@@ -9,7 +9,7 @@ use Catmandu::Store::Solr::CQL;
 use Catmandu::Error;
 use Moo;
 
-our $VERSION = "0.02151";
+our $VERSION = "0.02152";
 
 with 'Catmandu::Bag';
 with 'Catmandu::Searchable';
@@ -201,6 +201,9 @@ sub search {
     if ($res->spellcheck) {
         $hits->{spellcheck} = $res->spellcheck;
     }
+    if ( $res->content->{highlighting} ) {
+        $hits->{highlighting} = $res->content->{highlighting};
+    }
 
     $hits;
 }
